import 'package:http/http.dart' as http;
import 'dart:convert';

const String apiKey = "INCORPORAR_AQUI_VUESTRA_API_KEY";

class PrevisionMeteorologica {
  String municipio = "";
  String codigo = "";
  int precipitacion = 0;
  int tMax = 0;
  int tMin = 0;
  String estado = "";
  String valorEstado = "";
  String periodo = "";

  PrevisionMeteorologica(this.municipio, this.codigo);

  obtenerPrevision() async {
    /* Obtiene la previsión de forma síncrona */

    // Definimos la URL sobre la que haremos la petición
    String url =
        'https://opendata.aemet.es/opendata/api/prediccion/especifica/municipio/diaria/$codigo?api_key=$apiKey';

    // Lanzamos la petición GET al servidor, de forma síncrona
    // El resultado ya será la respuesta, no un Future
    var response = await http.get(Uri.parse(url));

    Map bodyJSON = {}; // Declaramos el mapa

    if (response.statusCode == 200) {
      // Respuesta válida
      bodyJSON = jsonDecode(response.body) as Map;
    }

    // Nueva petición GET con la URL de los datos
    // La petición es también síncrona
    var response2 = await http.get(Uri.parse(bodyJSON["datos"]));

    var infoMeteo = [];
    if (response2.statusCode == 200) {
      // Respuesta válida

      infoMeteo = jsonDecode(response2.body) as List;
      precipitacion =
          infoMeteo[0]["prediccion"]["dia"][0]["probPrecipitacion"][0]["value"];
      tMax = infoMeteo[0]["prediccion"]["dia"][0]["temperatura"]["maxima"];
      tMin = infoMeteo[0]["prediccion"]["dia"][0]["temperatura"]["minima"];

      // Estado del cielo -> Por franjas

      int i = 0;
      while (estado == "" && i < 7) {
        estado = infoMeteo[0]["prediccion"]["dia"][0]["estadoCielo"][i]
            ["descripcion"];
        valorEstado =
            infoMeteo[0]["prediccion"]["dia"][0]["estadoCielo"][i]["value"];
        periodo =
            infoMeteo[0]["prediccion"]["dia"][0]["estadoCielo"][i]["periodo"];
        i++;
      }
    }
  }

  void mostrar() {
    // Muestra por pantalla el estado de las propiedades
    print("Municipio: $municipio ($codigo)");
    print("Temperatura: $tMin - $tMax ");
    print("Estado del cielo [$periodo]: $estado ($valorEstado)");
  }
}

main() async {
  // Dado que obtienePrevision ahora es síncrona, deberemos esperar a
  // que finalice, de modo que la invocamos con await, y el main debe
  // ser marcado como async.

  PrevisionMeteorologica prevision =
      PrevisionMeteorologica("València", "46250");
  await prevision.obtenerPrevision();
  prevision.mostrar();
}
